@@ -52,9 +52,10 @@ typedef uint128_t uint128_t_a8 __attribute__ ((aligned(8)));
 
 typedef enum {
     MMDBW_SUCCESS,
-    MMDBW_FINDING_NODE_ERROR,
     MMDBW_INSERT_INTO_ALIAS_NODE_ERROR,
+    MMDBW_INSERT_INVALID_RECORD_TYPE_ERROR,
     MMDBW_FREED_ALIAS_NODE_ERROR,
+    MMDBW_FREED_FIXED_EMPTY_ERROR,
     MMDBW_FREED_FIXED_NODE_ERROR,
     MMDBW_ALIAS_OVERWRITE_ATTEMPT_ERROR,
     MMDBW_FIXED_NODE_OVERWRITE_ATTEMPT_ERROR,
@@ -63,10 +64,22 @@ typedef enum {
 
 typedef enum {
     MMDBW_RECORD_TYPE_EMPTY,
+    // Fixed empty records are like empty records in that they say there is no
+    // information. They are also immutable. And similar to alias records, you
+    // can't replace them, insert networks containing them, or insert networks
+    // belonging to them.
+    //
+    // We can't use EMPTY because they are not immutable. We can't use
+    // FIXED_NODE because they allow children (adding sub-networks). We can't
+    // use ALIAS as it has a special meaning, and we don't permit lookups to
+    // work (although that is only used in test code apparently). They also
+    // raise errors in some cases where FIXED_EMPTY currently does not.
+    MMDBW_RECORD_TYPE_FIXED_EMPTY,
     MMDBW_RECORD_TYPE_DATA,
     MMDBW_RECORD_TYPE_NODE,
-    // fixed nodes are used for nodes that other nodes alias; they cannot be
-    // removed without corrupting the tree.
+    // Fixed nodes are used for nodes that other nodes alias; they cannot be
+    // removed without corrupting the tree. Unlike FIXED_EMPTY, they can have
+    // children.
     MMDBW_RECORD_TYPE_FIXED_NODE,
     MMDBW_RECORD_TYPE_ALIAS,
 } MMDBW_record_type;
@@ -81,6 +94,7 @@ typedef enum {
 
 typedef struct MMDBW_record_s {
     union {
+        // Data records have a key into the tree's data table, a hash.
         const char *key;
         struct MMDBW_node_s *node;
     } value;
@@ -114,7 +128,6 @@ typedef struct MMDBW_tree_s {
     MMDBW_merge_cache_s *merge_cache;
     MMDBW_record_s root_record;
     uint32_t node_count;
-    bool is_aliased;
 } MMDBW_tree_s;
 
 typedef struct MMDBW_network_s {
@@ -132,7 +145,8 @@ typedef void (MMDBW_iterator_callback)(MMDBW_tree_s *tree,
     /* --prototypes automatically generated by dev-bin/regen-prototypes.pl - don't remove this comment */
     extern MMDBW_tree_s *new_tree(const uint8_t ip_version, uint8_t record_size,
                                   MMDBW_merge_strategy merge_strategy,
-                                  const bool alias_ipv6);
+                                  const bool alias_ipv6,
+                                  const bool remove_reserved_networks);
     extern void insert_network(MMDBW_tree_s *tree, const char *ipstr,
                                const uint8_t prefix_length, SV *key_sv, SV *data,
                                MMDBW_merge_strategy merge_strategy);
@@ -152,7 +166,8 @@ typedef void (MMDBW_iterator_callback)(MMDBW_tree_s *tree,
     extern MMDBW_tree_s *thaw_tree(char *filename, uint32_t initial_offset,
                                    uint8_t ip_version, uint8_t record_size,
                                    MMDBW_merge_strategy merge_strategy,
-                                   const bool alias_ipv6);
+                                   const bool alias_ipv6,
+                                   const bool remove_reserved_networks);
     extern void write_search_tree(MMDBW_tree_s *tree, SV *output,
                                   SV *root_data_type, SV *serializer);
     extern uint32_t max_record_value(MMDBW_tree_s *tree);
@@ -164,7 +179,5 @@ typedef void (MMDBW_iterator_callback)(MMDBW_tree_s *tree,
     extern SV *data_for_key(MMDBW_tree_s *tree, const char *const key);
     extern void free_tree(MMDBW_tree_s *tree);
     extern void free_merge_cache(MMDBW_tree_s *tree);
-    extern void warn_hex(uint8_t digest[16], char *where);
-    extern char *md5_as_hex(uint8_t digest[16]);
     /* --prototypes end - don't remove this comment-- */
     /* *INDENT-ON* */
