@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.013002;
 
-our $VERSION = '0.202000';
+our $VERSION = '0.300000';
 
 1;
 
@@ -22,7 +22,7 @@ MaxMind::DB::Writer - Create MaxMind DB database files
 
 =head1 VERSION
 
-version 0.202000
+version 0.300000
 
 =head1 SYNOPSIS
 
@@ -44,7 +44,7 @@ version 0.202000
     );
 
     $tree->insert_network(
-        '2001:db8::/48',
+        '8.8.8.0/24',
         {
             color => 'blue',
             dogs  => [ 'Fido', 'Ms. Pretty Paws' ],
@@ -109,7 +109,7 @@ Mark Fowler <mfowler@maxmind.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Florian Ragwitz Jan Bieron tjmather
+=for stopwords Florian Ragwitz Jan Bieron tjmather William Storey
 
 =over 4
 
@@ -125,11 +125,15 @@ Jan Bieron <jbieron+github@gmail.com>
 
 tjmather <tjmather@maxmind.com>
 
+=item *
+
+William Storey <wstorey@maxmind.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by MaxMind, Inc.
+This software is copyright (c) 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
