@@ -5,7 +5,7 @@ use warnings;
 use namespace::autoclean;
 use autodie;
 
-our $VERSION = '0.202000';
+our $VERSION = '0.300000';
 
 use IO::Handle;
 use Math::Int64 0.51;
@@ -175,6 +175,7 @@ sub _build_tree {
         $self->record_size,
         $self->merge_strategy,
         $self->alias_ipv6_to_ipv4,
+        $self->remove_reserved_networks,
     );
 }
 
@@ -287,8 +288,6 @@ sub write_tree {
     my $self   = shift;
     my $output = shift;
 
-    $self->_maybe_remove_reserved_networks;
-
     $self->_write_search_tree(
         $output,
         $self->_root_data_type(),
@@ -303,61 +302,6 @@ sub write_tree {
     );
 }
 
-{
-    my @reserved_4 = qw(
-        0.0.0.0/8
-        10.0.0.0/8
-        100.64.0.0/10
-        127.0.0.0/8
-        169.254.0.0/16
-        172.16.0.0/12
-        192.0.0.0/29
-        192.0.2.0/24
-        192.88.99.0/24
-        192.168.0.0/16
-        198.18.0.0/15
-        198.51.100.0/24
-        203.0.113.0/24
-        224.0.0.0/4
-        240.0.0.0/4
-    );
-
-    # ::/128 and ::1/128 are reserved under IPv6 but these are already covered
-    # under 0.0.0.0/8. We include all of 2001::/23 except 2001::/32 as the
-    # latter is Teredo, which is globally routable.
-    my @reserved_6 = (
-        @reserved_4, qw(
-            100::/64
-            2001:1::/32
-            2001:2::/31
-            2001:4::/30
-            2001:8::/29
-            2001:10::/28
-            2001:20::/27
-            2001:40::/26
-            2001:80::/25
-            2001:100::/24
-            2001:db8::/32
-            fc00::/7
-            fe80::/10
-            ff00::/8
-            )
-    );
-
-    sub _maybe_remove_reserved_networks {
-        my $self = shift;
-
-        return unless $self->remove_reserved_networks;
-
-        my @reserved = @reserved_4;
-        push @reserved, @reserved_6 if $self->ip_version == 6;
-
-        for my $network (@reserved) {
-            $self->remove_network($network);
-        }
-    }
-}
-
 {
     my %key_types = (
         binary_format_major_version => 'uint16',
@@ -481,6 +425,7 @@ sub new_from_frozen_tree {
                 record_size
                 merge_strategy
                 alias_ipv6_to_ipv4
+                remove_reserved_networks
                 )
         },
     );
@@ -519,7 +464,7 @@ MaxMind::DB::Writer::Tree - Tree representing a MaxMind DB database in memory -
 
 =head1 VERSION
 
-version 0.202000
+version 0.300000
 
 =head1 SYNOPSIS
 
@@ -541,7 +486,7 @@ version 0.202000
     );
 
     $tree->insert_network(
-        '2001:db8::/48',
+        '8.8.8.0/24',
         {
             color => 'blue',
             dogs  => [ 'Fido', 'Ms. Pretty Paws' ],
@@ -744,7 +689,10 @@ This is the 6to4 range
 =back
 
 When aliasing is enabled, insertions into the aliased locations will throw an
-exception. To insert an IPv4 address, insert it using IPv4 notation or insert
+exception. Inserting a network containing them does not throw an exception, but
+no information will be stored for the aliased locations.
+
+To insert an IPv4 address, insert it using IPv4 notation or insert
 directly into ::/96.
 
 Aliased nodes are I<not> followed when merging nodes. Only merges into the
@@ -754,10 +702,16 @@ This parameter is optional. It defaults to false.
 
 =item * remove_reserved_networks
 
-If this is true, reserved networks will be removed from the database by
-C<write_tree()> before the tree is written to the file handle. Reserved
-networks that are globally routable to an individual device, such as Teredo,
-are I<not> removed. The default is true.
+If this is true, reserved networks may not be inserted.
+
+Attempts to insert these networks or any inside them will be silently ignored.
+Inserting a network containing them does not throw an exception, but no
+information will be stored for the reserved sections.
+
+Reserved networks that are globally routable to an individual device, such as
+Teredo, may still be added.
+
+This parameter is optional. It defaults to true.
 
 =back
 
@@ -1093,7 +1047,7 @@ Mark Fowler <mfowler@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by MaxMind, Inc.
+This software is copyright (c) 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
